@@ -39,6 +39,9 @@
 #ifdef G_OS_UNIX
 #include "gdesktopappinfo.h"
 #endif
+#ifdef G_OS_WIN32
+#include "gregistrysettingsbackend.h"
+#endif
 #include <glib/gstdio.h>
 
 /**
@@ -596,6 +599,7 @@ _g_io_modules_ensure_loaded (void)
 #ifdef G_OS_WIN32
       _g_win32_volume_monitor_get_type ();
       g_win32_directory_monitor_get_type ();
+      g_registry_backend_get_type ();
 #endif
 #ifdef G_OS_UNIX
       _g_unix_volume_monitor_get_type ();
@@ -787,7 +791,13 @@ extension_prio_compare (gconstpointer  a,
 {
   const GIOExtension *extension_a = a, *extension_b = b;
 
-  return extension_b->priority - extension_a->priority;
+  if (extension_a->priority > extension_b->priority)
+    return -1;
+
+  if (extension_b->priority > extension_a->priority)
+    return 1;
+
+  return 0;
 }
 
 /**
