@@ -1764,7 +1764,7 @@ extern BOOL          _pcre_is_newline(USPTR, int, USPTR, int *, BOOL);
 extern int           _pcre_ord2utf8(int, uschar *);
 extern real_pcre    *_pcre_try_flipped(const real_pcre *, real_pcre *,
                        const pcre_study_data *, pcre_study_data *);
-extern int           _pcre_valid_utf8(USPTR, int);
+#define              _pcre_valid_utf8(u, i) TRUE
 extern BOOL          _pcre_was_newline(USPTR, int, USPTR, int *, BOOL);
 extern BOOL          _pcre_xclass(int, const uschar *);
 
@@ -1782,7 +1782,7 @@ extern const uschar      _pcre_ucd_stage1[];
 extern const pcre_uint16 _pcre_ucd_stage2[];
 extern const int         _pcre_ucp_gentype[];
 
-extern unsigned int      _pcre_ucp_othercase (unsigned int);
+extern unsigned int      _pcre_ucp_othercase (const unsigned int);
 
 /* UCD access macros */
 
